

[![Build Status](https://travis-ci.org/sonic182/carrera.svg?branch=master)](https://travis-ci.org/sonic182/carrera)
[![Coverage Status](https://coveralls.io/repos/github/sonic182/carrera/badge.svg?branch=master)](https://coveralls.io/github/sonic182/carrera?branch=master)
[![Documentation Status](https://readthedocs.org/projects/carrera/badge/?version=latest)](https://carrera.readthedocs.io/en/latest/?badge=latest)

# Carrera

Concurrency Framework

# Diagram

![Diagram](./carrera.png)


# Development

Install package
```bash
pip install -e ".[test]"
```

Develop... an then run test with pytest
```bash
pytest
```

# Contribute

1. Fork
2. create a branch `feature/your_feature`
3. commit - push - pull request

Thanks :)
